All Classes and Interfaces
Class
Description
Wraps an initially-null reference.
Helps to interpret method signatures within this library when downstream projects use NullAway.
Helper methods related to jSpecify nullness checking.
Provides helper methods to succinctly deal with null values.
Provides helper methods to succinctly deal with null values (NullAway friendly version).
A last-in-first-out stack of objects.